From: "Gerd Möllmann" <gerd.moellmann@gmail.com>
To: Eli Zaretskii <eliz@gnu.org>
Cc: 71763@debbugs.gnu.org, daniel@dpettersson.net
Subject: bug#71763: [PATCH] Inconsistency in bitmap overlay drawing for macOS
Date: Sun, 27 Oct 2024 15:03:32 +0100 [thread overview]
Message-ID: <m2plnl63t7.fsf@gmail.com> (raw)
In-Reply-To: <86o7358xz7.fsf@gnu.org> (Eli Zaretskii's message of "Sun, 27 Oct 2024 15:41:16 +0200")
Eli Zaretskii <eliz@gnu.org> writes:
>> Didn't even know until a few minutes ago that the cursor can land in
>> the fringe.
>
> See overflow-newline-into-fringe. It was added in Emacs 22 (and is ON
> by default, as you can see by typing enough characters on a line and
> ending the line with a newline, such that the last character before
> the newline fits completely on the screen line).
Indeed, never noticed, thanks!
>
>> And I'm wondering if that ever happens in the left fringe,
>
> It can, if the window shows RTL text, which starts at the right edge
> of the window.
>
>> and/or if the overlay arrow appears only on the left.
>
> In an RTL buffer, the arrow should appear on the right.
Yeah, of course :-).
>
>> Anyway. Assuming that I read the code correctly, that we are drawing a
>> cursor and overlay arrow on top of each other, then I think Daniel's
>> patch makes sense, because drawing the overlay arrow should not clear
>> under it and erase what was drawn for the cursor before.
>>
>> That's about what I could find out. NS should do something different if
>> overlay_p is set or not, I think that's for sure. And if Daniel says it
>> works, that's goog enough for me I guess.
>
> Thanks. If possible, can you also tell what the current code does
> wrong, that this patch fixes?
diff --git a/src/nsterm.m b/src/nsterm.m
index 794630de1c1..fc9133071ed 100644
--- a/src/nsterm.m
+++ b/src/nsterm.m
@@ -2961,24 +2961,28 @@ Hide the window (X11 semantics)
NSTRACE_MSG ("which:%d cursor:%d overlay:%d width:%d height:%d period:%d",
p->which, p->cursor_p, p->overlay_p, p->wd, p->h, p->dh);
- /* Work out the rectangle we will need to clear. */
- clearRect = NSMakeRect (p->x, p->y, p->wd, p->h);
+ /* Clear screen unless overlay. */
+ if ( !p->overlay_p )
+ {
+ /* Work out the rectangle we will need to clear. */
+ clearRect = NSMakeRect (p->x, p->y, p->wd, p->h);
If I read the diff correctly, this puts the clearing under the bitmap in
an if-statement so that it is only done if we do not draw intentionally
on top something drawn before.
Right, Daniel?
next prev parent reply other threads:[~2024-10-27 14:03 UTC|newest]
Thread overview: 9+ messages / expand[flat|nested] mbox.gz Atom feed top
2024-06-24 22:04 bug#71763: [PATCH] Inconsistency in bitmap overlay drawing for macOS Daniel Pettersson
2024-06-27 9:35 ` Eli Zaretskii
2024-10-27 10:26 ` Daniel Pettersson
2024-10-27 12:02 ` Eli Zaretskii
2024-10-27 13:23 ` Gerd Möllmann
2024-10-27 13:41 ` Eli Zaretskii
2024-10-27 14:03 ` Gerd Möllmann [this message]
2024-10-29 19:59 ` Daniel Pettersson
2024-10-30 7:11 ` Gerd Möllmann
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
List information: https://www.gnu.org/software/emacs/
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=m2plnl63t7.fsf@gmail.com \
--to=gerd.moellmann@gmail.com \
--cc=71763@debbugs.gnu.org \
--cc=daniel@dpettersson.net \
--cc=eliz@gnu.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
Code repositories for project(s) associated with this public inbox
https://git.savannah.gnu.org/cgit/emacs.git
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).